#! /bin/sh

usage() {
  echo ""
  echo "-------------------------------------------------------------------"
	echo Usage: "$0" \<startup speed\> \<fpr\> \<serial number\>
	echo "Startup speed can be 'fast' or 'slow'."
	echo " fast : The clock will not check for a modem."
	echo " slow : The clock will check whether a modem is attached on startup."
	echo "Set fpr to configure fingerprint reader"
	echo " -    : None"
	echo " f    : Futronix reader"
	echo " l    : Lumidigm reader"
  echo "-------------------------------------------------------------------"
	echo ""
	exit 1
}

if [ $# != 3 ]
then
	usage
fi

if [[ "$1" == "fast" || "$1" == "slow" ]]
then
	echo "Modem value is valid"
else
	usage
fi

if [[ "$2" == "-" || "$2" == "f" || "$2" == "l" ]]
then
	echo "FPR value is valid"
else
	usage
fi

if [[ $3 =~ ^[0-9]* ]] && [[ $3 -gt 0 ]];
then
	echo "Serial number is an integer"
else
	usage
fi

echo ""
echo " ----- Setting up Clock ----- "
echo ""

# Get the USB drive ready
echo " Formatting USB drive"
/usr/local/bin/formatusb.sh -detect

while [ $(pidof /usr/local/bin/formatusb.sh) ]
do
	sleep 1
done

echo " Detect big flash init"
/usr/local/bin/dbf.sh usb

while [ ! -e "/var/local/data/capeclock.db" ]
do
	sleep 1
done

# Set serial number
echo Setting serial to "$3"
#/usr/local/bin/setserial.sh "$3"
echo "$3" > /var/local/data/SerialNumber.txt
echo "$3" > /var/sdcard/data/SerialNumber.txt
hostname CSTC$3
echo "CSTC$3" > /etc/hostname
/etc/init.d/samba restart

# Set up fast or slow start up
if [[ $1 == "fast" ]]
then
	/usr/local/bin/sqlite3shell /var/local/data/capeclock.db "update thisdev set modem = 2 where id  = 1;"
fi

if [[ $1 == "slow" ]]
then
	/usr/local/bin/sqlite3shell /var/local/data/capeclock.db "update thisdev set modem = 0 where id  = 1;"
fi

if [[ $2 = "f" || $2 = "l" ]]
then
	sleep 1
	# Start clock to have the daughter table populated
	/usr/local/bin/startclock

	#Wait for daughter table to be populated (ASSUMES ONLY 1 DAUGHTER TABLE)
	while [[ $(/usr/local/bin/sqlite3shell /var/local/data/capeclock.db "select count(*) from daughter;") -ne 1 ]]
	do
		sleep 1
	done

	sleep 1
	/usr/local/bin/stopclock
	sleep 1

	DSERIAL=$(/usr/local/bin/sqlite3shell /var/local/data/capeclock.db "select serial from daughter;")
	# Set up fpr
	if [[ $2 == "f" ]]
	then
		/usr/local/bin/sqlite3shell /var/local/data/capeclock.db "update daughter set comportf1=5, tyf1=265 where serial  = $DSERIAL;"
	elif [[ $2 == "l" ]]
	then
		/usr/local/bin/sqlite3shell /var/local/data/capeclock.db "update daughter set comportf1=5, tyf1=289 where serial  = $DSERIAL;"
	fi
else
	echo "No fingerprint reader"
fi

echo ""
echo " ----- Done ----- "
echo ""

echo ""
echo " ----- Summary ----- "
echo ""
echo "Modem setting:"
/usr/local/bin/sqlite3shell /var/local/data/capeclock.db "select modem from thisdev where id  = 1;"
if [[ $2 != "-" ]]
then
	echo "FPR settings"
	/usr/local/bin/sqlite3shell -header /var/local/data/capeclock.db "select serial, comportf1, tyf1 from daughter where serial  = $DSERIAL;"
fi
echo "Serial:"
cat /var/local/data/SerialNumber.txt
echo ""
echo " ------------------- "
echo ""

sleep 2
/usr/local/bin/startclock

exit 0
